Exception: ApiSerializer::Errors::DataTransformError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/api_serializer/errors/data_transform_error.rb

Instance Method Summary collapse

Constructor Details

#initialize(message = "The data transferred failed as the data does not abide to the schema.") ⇒ DataTransformError

Returns a new instance of DataTransformError.



4
5
6
# File 'lib/api_serializer/errors/data_transform_error.rb', line 4

def initialize(message = "The data transferred failed as the data does not abide to the schema.")
  super
end