Exception: ApiSerializer::Errors::DataTransformError
- Inherits:
-
StandardError
- Object
- StandardError
- ApiSerializer::Errors::DataTransformError
- Defined in:
- lib/api_serializer/errors/data_transform_error.rb
Instance Method Summary collapse
-
#initialize(message = "The data transferred failed as the data does not abide to the schema.") ⇒ DataTransformError
constructor
A new instance of DataTransformError.
Constructor Details
#initialize(message = "The data transferred failed as the data does not abide to the schema.") ⇒ DataTransformError
Returns a new instance of DataTransformError.
4 5 6 |
# File 'lib/api_serializer/errors/data_transform_error.rb', line 4 def initialize( = "The data transferred failed as the data does not abide to the schema.") super end |